import URI from '@vscode/base-node/vs/base/common/uri';
import Event from '@vscode/base-node/vs/base/common/event';
import { IDisposable } from '@vscode/base-node/vs/base/common/lifecycle';
export interface IEditorService {
    openEditor(input: IResourceInput, sideBySide?: boolean): Promise<IEditor>;
}
export interface IEditorModel {
    onDispose: Event<void>;
    load(): Promise<IEditorModel>;
    dispose(): void;
}
export interface IBaseResourceInput {
    options?: ITextEditorOptions;
    label?: string;
    description?: string;
}
export interface IResourceInput extends IBaseResourceInput {
    resource: URI;
    enconding?: string;
}
export interface IUntitledResourceInput extends IBaseResourceInput {
    resource?: URI;
    filePath?: string;
    language?: string;
    contents?: string;
    encoding?: string;
}
export interface IResourceDiffInput extends IBaseResourceInput {
    leftResource: URI;
    rightResource: URI;
}
export interface IResourceSideBySideInput extends IBaseResourceInput {
    masterResource: URI;
    detailResource: URI;
}
export interface IEditorControl {
}
export interface IEditor {
    input: IEditorInput;
    options: IEditorOptions;
    position: Position;
    getId(): string;
    getControl(): IEditorControl;
    focus(): void;
    isVisible(): boolean;
}
export declare enum Position {
    ONE = 0,
    TWO = 1,
    THREE = 2,
}
export declare const POSITIONS: Position[];
export declare enum Direction {
    LEFT = 0,
    RIGHT = 1,
}
export declare enum Verbosity {
    SHORT = 0,
    MEDIUM = 1,
    LONG = 2,
}
export interface IEditorInput extends IDisposable {
    onDispose: Event<void>;
    getName(): string;
    getDescription(verbosity?: Verbosity): string;
    getTitle(verbosity?: Verbosity): string;
    resolve(): Promise<IEditorModel>;
    isDirty(): boolean;
    revert(): Promise<boolean>;
    matches(other: any): boolean;
}
export interface IEditorOptions {
    preserveFocus?: boolean;
    forceOpen?: boolean;
    revealIfVisible?: boolean;
    revealIfOpened?: boolean;
    pinned?: boolean;
    index?: number;
    inactive?: boolean;
}
export interface ITextEditorSelection {
    startLineNumber: number;
    startColumn: number;
    endLineNumber?: number;
    endColumn?: number;
}
export interface ITextEditorOptions extends IEditorOptions {
    selection?: ITextEditorSelection;
    viewState?: object;
    revealInCenterIfOutsideViewport?: boolean;
}
export declare const EDITOR_DEFAULT_HEIGHT = 80;
